{% extends "base.html" %}
{% load static i18n %}

{% block title %}{{title}}{% endblock title %}

{% block content %}
    <p class="bg-secondary text-white p-3">{{summary}}</p>
    <div class="btn-group-vertical">
        <a href="{% url 'odk:xform_list' %}" class="btn btn-primary">{% trans "Available form" %}</a>
        <br> 
        <a href="{% url 'odk:xformsubmit_list' %}" class="btn btn-primary">{% trans "Submitted form" %}</a>
    </div>

{% endblock content %}