# Generated by Django 4.0.5 on 2022-06-21 09:00

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('odk', '0003_remove_xform_modified_by_remove_xform_modified_on_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xform',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='xform_created_by', to=settings.AUTH_USER_MODEL, verbose_name='Created by'),
        ),
        migrations.AlterField(
            model_name='xform',
            name='xml_content',
            field=models.TextField(blank=True, null=True, verbose_name='Content of XML form'),
        ),
    ]
